@@ -1,17 +1,22 @@
+"""
+Modified from https://github.com/pytorch/vision/blob/main/torchvision/models/googlenet.py
+"""
 import warnings
 from collections import namedtuple
+from typing import Optional, Tuple, List, Callable, Any
+
 import oneflow as flow
 import oneflow.nn as nn
 import oneflow.nn.functional as F
 from oneflow import Tensor
+
 from .utils import load_state_dict_from_url
-from typing import Optional, Tuple, List, Callable, Any
 from .registry import ModelCreator
 
 __all__ = ["GoogLeNet", "googlenet", "GoogLeNetOutputs", "_GoogLeNetOutputs"]
 
 model_urls = {
-    "googlenet": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/Inception/googlenet.zip",
+    "googlenet": "https://oneflow-public.oss-cn-beijing.aliyuncs.com/model_zoo/flowvision/classification/Inception/googlenet.zip",
 }
 
 GoogLeNetOutputs = namedtuple(
@@ -32,16 +37,28 @@ _GoogLeNetOutputs = GoogLeNetOutputs
 def googlenet(
     pretrained: bool = False, progress: bool = True, **kwargs: Any
 ) -> "GoogLeNet":
-    r"""GoogLeNet (Inception v1) model architecture from
-    `"Going Deeper with Convolutions" <http://arxiv.org/abs/1409.4842>`_.
+    """
+    Constructs the GoogLeNet (Inception v1) model.
+
+    .. note::
+        GoogLeNet (Inception v1) model from the `Going Deeper with Convolutions <http://arxiv.org/abs/1409.4842>`_ paper.
+        The required minimum input size of the model is 15x15.
 
     Args:
-        pretrained (bool): If True, returns a model pre-trained on ImageNet
-        progress (bool): If True, displays a progress bar of the download to stderr
+        pretrained (bool): Whether to download the pre-trained model on ImageNet. Default: ``False``
+        progress (bool): If True, displays a progress bar of the download to stderrt. Default: ``True``
         aux_logits (bool): If True, adds two auxiliary branches that can improve training.
             Default: *False* when pretrained is True otherwise *True*
         transform_input (bool): If True, preprocesses the input according to the method with which it
             was trained on ImageNet. Default: *False*
+
+    For example:
+
+    .. code-block:: python
+
+        >>> import flowvision
+        >>> googlenet = flowvision.models.googlenet(pretrained=False, progress=True)
+
     """
     if pretrained:
         if "transform_input" not in kwargs:
@@ -55,7 +72,6 @@ def googlenet(
             )
         original_aux_logits = kwargs["aux_logits"]
         kwargs["aux_logits"] = True
-        kwargs["init_weights"] = False
         model = GoogLeNet(**kwargs)
         state_dict = load_state_dict_from_url(
             model_urls["googlenet"], progress=progress
@@ -84,14 +100,10 @@ class GoogLeNet(nn.Module):
         super(GoogLeNet, self).__init__()
         if blocks is None:
             blocks = [BasicConv2d, Inception, InceptionAux]
+
         if init_weights is None:
-            warnings.warn(
-                "The default weight initialization of GoogleNet will be changed in future releases of "
-                "torchvision. If you wish to keep the old behavior (which leads to long initialization times"
-                " due to scipy/scipy#11299), please set init_weights=True.",
-                FutureWarning,
-            )
             init_weights = True
+
         assert len(blocks) == 3
         conv_block = blocks[0]
         inception_block = blocks[1]
@@ -238,7 +250,6 @@ class Inception(nn.Module):
         self.branch3 = nn.Sequential(
             conv_block(in_channels, ch5x5red, kernel_size=1),
             # Here, kernel_size=3 instead of kernel_size=5 is a known bug.
-            # Please see https://github.com/pytorch/vision/issues/906 for details.
             conv_block(ch5x5red, ch5x5, kernel_size=3, padding=1),
         )
 
